"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isConfigPath = isConfigPath;
exports.hasConfigPathIntersection = hasConfigPathIntersection;

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

/** @public */

/**
 * Checks whether specified value can be considered as config path.
 * @param value Value to check.
 * @internal
 */
function isConfigPath(value) {
  if (!value) {
    return false;
  }

  if (typeof value === 'string') {
    return true;
  }

  return Array.isArray(value) && value.every(segment => typeof segment === 'string');
}
/**
 * Represents config store.
 * @internal
 */


const pathDelimiter = '.';

function hasConfigPathIntersection(leafPath, rootPath) {
  if (!leafPath) {
    throw new Error('leafPath cannot be empty');
  }

  if (!rootPath) {
    throw new Error('rootPath cannot be empty');
  }

  const leafSegments = leafPath.split(pathDelimiter);
  const rootSegments = rootPath.split(pathDelimiter);
  return rootSegments.every((rootSegment, index) => leafSegments[index] === rootSegment);
}